;; Generated package description from debbugs.el
(define-package "debbugs" "0.7" "SOAP library to access debbugs servers" 'nil :url "http://elpa.gnu.org/packages/debbugs.html" :keywords '("comm" "hypermedia"))
